@@ -44,7 +44,7 @@ import Data.Conduit.OpenPGP.Keyring (conduitToTKsDropping, sinkKeyringMap)
 import Data.Conduit.Serialization.Binary (conduitGet)
 import Data.Data.Lens (biplate)
 import Data.Either (rights)
-import qualified Data.IxSet as IxSet
+import qualified Data.IxSet.Typed as IxSet
 import Data.Graph.Inductive.Graph (Graph(mkGraph), emap, Path, prettyPrint)
 import Data.Graph.Inductive.PatriciaTree (Gr)
 import Data.Graph.Inductive.Query.SP (sp)
@@ -74,6 +74,7 @@ import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, stderr, hSetBuffering, BufferMode(..))
 import Text.PrettyPrint.ANSI.Leijen ((<+>), (</>), hardline, hPutDoc, list, putDoc, text)
+import Text.PrettyPrint.Free (pretty)
 
 grabMatchingKeysConduit :: MonadResource m => FilePath -> Bool -> Text -> Source m TK
 grabMatchingKeysConduit fp filt srch = CB.sourceFile fp $= conduitGet get $= conduitToTKsDropping $= (if filt then conduitTKFilter ufp else CL.filter matchAny)
@@ -117,7 +118,7 @@ tkToTKey tk = TKey {
         mkey = Key <$> either (const Nothing) Just . pubkeySize . _pubkey
                    <*> show . _pkalgo
                    <*> pkalgoAbbrev . _pkalgo
-                   <*> either (const "unknown") show . eightOctetKeyID
+                   <*> either (const "unknown") (show . pretty) . eightOctetKeyID
                    <*> show . fingerprint
 
 showTKey :: TKey -> IO ()
@@ -255,7 +256,10 @@ doExportPubkeys :: Options -> IO ()
 doExportPubkeys o = do
     let ttarget1 = T.pack . target1
     keys <- grabMatchingKeys (keyring o) (targetIsFilter o) (ttarget1 o)
-    mapM_ (BL.putStr . putTK') keys
+    case pathsOutputFormat o of
+        Unstructured -> mapM_ (BL.putStr . putTK') keys
+        JSON -> BL.putStr . A.encode $ keys
+        YAML -> B.putStr . Y.encode $ keys
     where
         putTK' key = runPut $ do
             put (PublicKey (key^.tkKey._1))
@@ -277,7 +281,7 @@ doGraph o = do
         LossyPretty -> prettyPrint g
         GraphViz -> TLIO.putStrLn . printDotGraph . graphToDot nonClusteredLabeledNodesParams $ g
     where
-        nonClusteredLabeledNodesParams = nonClusteredParams { fmtNode = \(_,l) -> [toLabel $ show l] }
+        nonClusteredLabeledNodesParams = nonClusteredParams { fmtNode = \(_,l) -> [toLabel $ show (pretty l)] }
 
 buildMaps :: [TK] -> (KeyMaps, Int)
 buildMaps ks = S.execState (mapM_ mapsInsertions ks) (KeyMaps HashMap.empty HashMap.empty HashMap.empty, 0)
